==> com.liferay.marketplace.app.manager.web-2.0.7-sources.jar: com/liferay/marketplace/app/manager/web/internal/constants/BundleConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.marketplace.app.manager.web.internal.constants;

import org.osgi.framework.Constants;

/**
 * @author Ryan Park
 */
public interface BundleConstants extends Constants {

	public static final String LIFERAY_RELENG_APP_DESCRIPTION =
		"Liferay-Releng-App-Description";

	public static final String LIFERAY_RELENG_APP_TITLE =
		"Liferay-Releng-App-Title";

	public static final String LIFERAY_RELENG_BUNDLE = "Liferay-Releng-Bundle";

	public static final String LIFERAY_RELENG_CATEGORY =
		"Liferay-Releng-Category";

	public static final String LIFERAY_RELENG_DEMO_URL =
		"Liferay-Releng-Demo-Url";

	public static final String LIFERAY_RELENG_DEPENDENT_APPS =
		"Liferay-Releng-Dependent-Apps";

	public static final String LIFERAY_RELENG_LABS = "Liferay-Releng-Labs";

	public static final String LIFERAY_RELENG_MARKETPLACE =
		"Liferay-Releng-Marketplace";

	public static final String LIFERAY_RELENG_PUBLIC = "Liferay-Releng-Public";

	public static final String LIFERAY_RELENG_SUITE_DESCRIPTION =
		"Liferay-Releng-Suite-Description";

	public static final String LIFERAY_RELENG_SUITE_TITLE =
		"Liferay-Releng-Suite-Title";

	public static final String LIFERAY_RELENG_SUPPORT_URL =
		"Liferay-Releng-Support-Url";

	public static final String LIFERAY_RELENG_SUPPORTED =
		"Liferay-Releng-Supported";

}

==> com.liferay.marketplace.app.manager.web-3.0.7-sources.jar: com/liferay/marketplace/app/manager/web/internal/constants/BundleConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.marketplace.app.manager.web.internal.constants;

/**
 * @author Ryan Park
 */
public interface BundleConstants {

	public static final String LIFERAY_RELENG_APP_DESCRIPTION =
		"Liferay-Releng-App-Description";

	public static final String LIFERAY_RELENG_APP_TITLE =
		"Liferay-Releng-App-Title";

	public static final String LIFERAY_RELENG_BUNDLE = "Liferay-Releng-Bundle";

	public static final String LIFERAY_RELENG_CATEGORY =
		"Liferay-Releng-Category";

	public static final String LIFERAY_RELENG_DEMO_URL =
		"Liferay-Releng-Demo-Url";

	public static final String LIFERAY_RELENG_DEPENDENT_APPS =
		"Liferay-Releng-Dependent-Apps";

	public static final String LIFERAY_RELENG_LABS = "Liferay-Releng-Labs";

	public static final String LIFERAY_RELENG_MARKETPLACE =
		"Liferay-Releng-Marketplace";

	public static final String LIFERAY_RELENG_PUBLIC = "Liferay-Releng-Public";

	public static final String LIFERAY_RELENG_SUITE_DESCRIPTION =
		"Liferay-Releng-Suite-Description";

	public static final String LIFERAY_RELENG_SUITE_TITLE =
		"Liferay-Releng-Suite-Title";

	public static final String LIFERAY_RELENG_SUPPORT_URL =
		"Liferay-Releng-Support-Url";

	public static final String LIFERAY_RELENG_SUPPORTED =
		"Liferay-Releng-Supported";

}
